@@ -8,6 +8,7 @@ import (
 	"io/fs"
 	"log/slog"
 	"os"
+	"strings"
 	"sync"
 
 	"github.com/derailed/k9s/internal/client"
@@ -19,17 +20,19 @@ import (
 	"k8s.io/apimachinery/pkg/util/sets"
 )
 
-// Alias tracks shortname to GVR mappings.
-type Alias map[string]*client.GVR
+type (
+	// Alias tracks shortname to GVR mappings.
+	Alias map[string]*client.GVR
 
-// ShortNames represents a collection of shortnames for aliases.
-type ShortNames map[*client.GVR][]string
+	// ShortNames represents a collection of shortnames for aliases.
+	ShortNames map[*client.GVR][]string
 
-// Aliases represents a collection of aliases.
-type Aliases struct {
-	Alias Alias `yaml:"aliases"`
-	mx    sync.RWMutex
-}
+	// Aliases represents a collection of aliases.
+	Aliases struct {
+		Alias Alias `yaml:"aliases"`
+		mx    sync.RWMutex
+	}
+)
 
 // NewAliases return a new alias.
 func NewAliases() *Aliases {
@@ -79,19 +82,28 @@ func (a *Aliases) Clear() {
 	}
 }
 
-func (a *Aliases) Resolve(command string) (*client.GVR, string, bool) {
-	agvr, ok := a.Get(command)
-	if !ok {
-		return nil, "", false
-	}
-
-	p := cmd.NewInterpreter(agvr.String())
+func (a *Aliases) Resolve(p *cmd.Interpreter) (*client.GVR, bool) {
 	gvr, ok := a.Get(p.Cmd())
 	if !ok {
-		return agvr, "", true
+		return nil, false
 	}
 
-	return gvr, p.Args(), true
+	if gvr.IsK8sRes() {
+		p.Reset(strings.Replace(p.GetLine(), p.Cmd(), gvr.String(), 1))
+		return gvr, true
+	}
+
+	for gvr.IsCommand() {
+		ap := cmd.NewInterpreter(gvr.String())
+		gvr, ok = a.Get(ap.Cmd())
+		if !ok {
+			return gvr, false
+		}
+		ap.Merge(p)
+		p.Reset(strings.Replace(ap.GetLine(), ap.Cmd(), gvr.String(), 1))
+	}
+
+	return gvr, true
 }
 
 // Get retrieves an alias.
@@ -108,6 +120,7 @@ func (a *Aliases) Get(alias string) (*client.GVR, bool) {
 func (a *Aliases) Define(gvr *client.GVR, aliases ...string) {
 	a.mx.Lock()
 	defer a.mx.Unlock()
+
 	for _, alias := range aliases {
 		if _, ok := a.Alias[alias]; !ok && alias != "" {
 			a.Alias[alias] = gvr
@@ -131,16 +144,6 @@ func (a *Aliases) Load(path string) error {
 	return a.LoadFile(path)
 }
 
-type aliases struct {
-	Alias map[string]string `yaml:"aliases"`
-}
-
-func newAliases(s int) aliases {
-	return aliases{
-		Alias: make(map[string]string, s),
-	}
-}
-
 // LoadFile loads alias from a given file.
 func (a *Aliases) LoadFile(path string) error {
 	if _, err := os.Stat(path); errors.Is(err, fs.ErrNotExist) {
@@ -155,15 +158,15 @@ func (a *Aliases) LoadFile(path string) error {
 		slog.Warn("Aliases validation failed", slogs.Error, err)
 	}
 
-	var aa aliases
-	if err := yaml.Unmarshal(bb, &aa); err != nil {
+	a.mx.Lock()
+	if err := yaml.Unmarshal(bb, a); err != nil {
 		return err
 	}
-	a.mx.Lock()
-	defer a.mx.Unlock()
-	for alias, cmd := range aa.Alias {
-		a.Alias[alias] = client.NewGVR(cmd)
+
+	for k, v := range a.Alias {
+		a.Alias[k] = client.NewGVR(v.String())
 	}
+	defer a.mx.Unlock()
 
 	return nil
 }
@@ -198,18 +201,17 @@ func (a *Aliases) loadDefaultAliases() {
 // Save alias to disk.
 func (a *Aliases) Save() error {
 	slog.Debug("Saving Aliases...")
-	return a.SaveAliases(AppAliasesFile)
+	a.mx.RLock()
+	defer a.mx.RUnlock()
+
+	return a.saveAliases(AppAliasesFile)
 }
 
 // SaveAliases saves aliases to a given file.
-func (a *Aliases) SaveAliases(path string) error {
+func (a *Aliases) saveAliases(path string) error {
 	if err := data.EnsureDirPath(path, data.DefaultDirMod); err != nil {
 		return err
 	}
-	aa := newAliases(len(a.Alias))
-	for alias, gvr := range a.Alias {
-		aa.Alias[alias] = gvr.String()
-	}
 
-	return data.SaveYAML(path, aa)
+	return data.SaveYAML(path, a)
 }
