@@ -4,16 +4,21 @@
 package port
 
 import (
+	"context"
 	"fmt"
+	"log/slog"
 	"net"
+
+	"github.com/derailed/k9s/internal/slogs"
 )
 
 // PortTunnels represents a collection of tunnels.
 type PortTunnels []PortTunnel
 
-func (t PortTunnels) CheckAvailable() error {
+// CheckAvailable checks if all port tunnels are available.
+func (t PortTunnels) CheckAvailable(ctx context.Context) error {
 	for _, pt := range t {
-		if !IsPortFree(pt) {
+		if !IsPortFree(ctx, pt) {
 			return fmt.Errorf("port %s is not available on host", pt.LocalPort)
 		}
 	}
@@ -26,6 +31,7 @@ type PortTunnel struct {
 	Address, Container, LocalPort, ContainerPort string
 }
 
+// NewPortTunnel returns a new instance.
 func NewPortTunnel(a, co, lp, cp string) PortTunnel {
 	return PortTunnel{
 		Address:       a,
@@ -45,13 +51,18 @@ func (t PortTunnel) PortMap() string {
 	if t.LocalPort == "" {
 		t.LocalPort = t.ContainerPort
 	}
+
 	return t.LocalPort + ":" + t.ContainerPort
 }
 
-func IsPortFree(t PortTunnel) bool {
-	s, err := net.Listen("tcp", fmt.Sprintf("%s:%s", t.Address, t.LocalPort))
+// IsPortFree checks if a address/port pair is available on host.
+func IsPortFree(ctx context.Context, t PortTunnel) bool {
+	var ncfg net.ListenConfig
+	s, err := ncfg.Listen(ctx, "tcp", fmt.Sprintf("%s:%s", t.Address, t.LocalPort))
 	if err != nil {
+		slog.Warn("Port is not available", slogs.Port, t.LocalPort, slogs.Address, t.Address)
 		return false
 	}
+
 	return s.Close() == nil
 }
